pub enum Command {
Stdout(String),
Stderr(String),
Stdin,
Readline,
Args,
Write(String, Vec<u8>),
}Expand description
A run-time command sent from a run-time function to a runtime_client
Variants
Stdout(String)
Command to print a String of contents to stdout
Stderr(String)
Command to print a String of contents to stderr
Stdin
Read characters possible from Stdin
Readline
Read a line of characters from Stdlin
Args
Get the arguments for the flow
Write(String, Vec<u8>)
Write to a file